# vasppy - a Python suite for manipulating VASP files

[![DOI](https://zenodo.org/badge/17946870.svg)](https://zenodo.org/badge/latestdoi/17946870)
[![PyPI version](https://badge.fury.io/py/vasppy.svg)](https://badge.fury.io/py/vasppy)
[![Build Status](https://travis-ci.org/bjmorgan/vasppy.svg?branch=master)](https://travis-ci.org/bjmorgan/vasppy)
[![Test Coverage](https://codeclimate.com/github/bjmorgan/vasppy/badges/coverage.svg)](https://codeclimate.com/github/bjmorgan/vasppy/coverage)
[![Documentation Status](https://readthedocs.org/projects/vasppy/badge/?version=latest)](http://vasppy.readthedocs.io/en/latest/?badge=latest)

`vasppy` is a suite of Python tools and scripts written in Python for manipulating and processing [VASP](https://www.vasp.at/) input and output files.

## Tests

Automated testing of the latest build happens [here](https://travis-ci.org/bjmorgan/vasppy).

Manual tests can be run using
```
python3 -m unittest discover
```

## API documentation

API documentation is hosted at [Read the Docs](http://vasppy.readthedocs.io/en/latest/).
